# setup.py

from setuptools import setup, find_packages

setup(
    name='estimate_population',
    version='0.1.2',
    packages=find_packages(),
    install_requires=[],
    entry_points={},
    python_requires='>=3.6',
)